from pydantic import BaseModel, Field

from switcore.ui.interactive_image import InteractiveImage


class ImageGrid(BaseModel):
    type: str = "image_grid"
    images: list[InteractiveImage]
    column_count: int = Field(..., ge=2, le=3)



from pydantic import BaseModel

from switcore.ui.button import Button
from switcore.ui.image import Image


class ContextMenuItem(BaseModel):
    label: str
    action_id: str


class Header(BaseModel):
    title: str
    subtitle: str | None = None
    context_menu: list[ContextMenuItem] | None = None
    buttons: list[Button] | None = None


class AttachmentHeader(BaseModel):
    title: str
    subtitle: str | None = None
    app_id: str
    icon: Image | None = None



from pydantic import BaseModel


class DatePicker(BaseModel):
    type: str = "datepicker"
    action_id: str
    placeholder: str | None = None
    trigger_on_input: bool = False
    value: str | None = None
